==> miniearth-sdk-1.1.1.tgz: package/src/core/effects/pipeline.js <==

const { Cesium } = BC.Namespace

class FlyWithTime {
  constructor(posList, opt) {
    var beforeOpt ={
      startTime: null,
      duration: 50000,
      /*model: {
        uri: '/assets/jingche.glb',
        scale: 1,
      },
      billboard: {
        image: '/assets/water.png',
        width: 500,
        scale: 0.05,
        sizeInMeters: true,
        verticalOrigin: Cesium.VerticalOrigin.BOTTOM, //垂直位置
        horizontalOrigin: Cesium.HorizontalOrigin.CENTER, //水平位置
        pixelOffset: new Cesium.Cartesian2(0, 0), //偏移
      }*/
    }
    this.posList = posList;
    this.opt = {}
    /*   this.opt.model = Object.assign(beforeOpt.model,opt?.model)
       this.opt.billboard = Object.assign(beforeOpt.billboard,opt?.billboard)*/
    this.opt.startTime = opt?.startTime || beforeOpt.startTime;
    this.opt.duration = opt?.duration || beforeOpt.duration;
    this.entity = null;
    this.init()
  }

  init() {
    if (!window.viewer) {
      console.error('地球未初始化，实体加载失败')
    }

    viewer.scene.globe.enableLighting = true;
    viewer.clock.shouldAnimate = true;
    var startTime = this.opt.startTime||viewer.clock.currentTime;
    // 结束时间
    var stop = Cesium.JulianDate.addSeconds(startTime, this.opt.duration, new Cesium.JulianDate());

    var timeProperty = this.getPositionProperty(this.posList, startTime);

    this.entity = viewer.entities.add({
      // 和时间轴关联
      availability: new Cesium.TimeIntervalCollection([new Cesium.TimeInterval({
        start: startTime,
        stop: stop
      })]),
      position: timeProperty,
      // 根据所提供的速度计算模型的朝向
      orientation: new Cesium.VelocityOrientationProperty(timeProperty),
      // 模型数据
      model: this.opt.model || null,
      billboard: this.opt.billboard || null,
      label:this.opt.label || null,
      point:this.opt.point || null,
    });
    console.log(this.opt)
  }
  getPositionProperty(source, start){
    // 取样位置 相当于一个集合
    let property = new Cesium.SampledPositionProperty();
    for (let i = 0; i < source.length; i++) {
      let time = Cesium.JulianDate.addSeconds(start, source[i].time, new Cesium.JulianDate);
      //console.log(time);
      let position = Cesium.Cartesian3.fromDegrees(source[i].lng, source[i].lat, source[i].alt);
      // 添加位置，和时间对应
      property.addSample(time, position);
    }
    return property;
  }

  start() {
    if (this.entity) {
      console.warn("实体已经初始化")
      return
    }
    this.init()
  }

  stop() {
    this.entity ? (this.entity.show = false) : ''
  }

  uninstall() {
    if (!this.entity) return
    viewer.entities.remove(this.entity)
    this.entity = null
  }

  zoomTo() {
    viewer.zoomTo(this.entity)
  }
}

export default FlyWithTime

==> miniearth-sdk-1.2.1.tgz: package/src/core/effects/pipeline.js <==

const { Cesium } = BC.Namespace

class FlyWithTime {
  constructor(posList, opt,viewer) {
    var beforeOpt ={
      startTime: null,
      duration: 50000,
      /*model: {
        uri: '/assets/jingche.glb',
        scale: 1,
      },
      billboard: {
        image: '/assets/water.png',
        width: 500,
        scale: 0.05,
        sizeInMeters: true,
        verticalOrigin: Cesium.VerticalOrigin.BOTTOM, //垂直位置
        horizontalOrigin: Cesium.HorizontalOrigin.CENTER, //水平位置
        pixelOffset: new Cesium.Cartesian2(0, 0), //偏移
      }*/
    }
    this.posList = posList;
    this.opt = {}
    /*   this.opt.model = Object.assign(beforeOpt.model,opt?.model)
       this.opt.billboard = Object.assign(beforeOpt.billboard,opt?.billboard)*/
    this.opt.startTime = opt?.startTime || beforeOpt.startTime;
    this.opt.duration = opt?.duration || beforeOpt.duration;
    this.entity = null;
    this.viewer =viewer;
    this.init()
  }

  init() {
    if (!this.viewer) {
      console.error('地球未初始化，实体加载失败')
    }

    this.viewer.scene.globe.enableLighting = true;
    this.viewer.clock.shouldAnimate = true;
    var startTime = this.opt.startTime||this.viewer.clock.currentTime;
    // 结束时间
    var stop = Cesium.JulianDate.addSeconds(startTime, this.opt.duration, new Cesium.JulianDate());

    var timeProperty = this.getPositionProperty(this.posList, startTime);

    this.entity = this.viewer.entities.add({
      // 和时间轴关联
      availability: new Cesium.TimeIntervalCollection([new Cesium.TimeInterval({
        start: startTime,
        stop: stop
      })]),
      position: timeProperty,
      // 根据所提供的速度计算模型的朝向
      orientation: new Cesium.VelocityOrientationProperty(timeProperty),
      // 模型数据
      model: this.opt.model || null,
      billboard: this.opt.billboard || null,
      label:this.opt.label || null,
      point:this.opt.point || null,
    });
    console.log(this.opt)
  }
  getPositionProperty(source, start){
    // 取样位置 相当于一个集合
    let property = new Cesium.SampledPositionProperty();
    for (let i = 0; i < source.length; i++) {
      let time = Cesium.JulianDate.addSeconds(start, source[i].time, new Cesium.JulianDate);
      //console.log(time);
      let position = Cesium.Cartesian3.fromDegrees(source[i].lng, source[i].lat, source[i].alt);
      // 添加位置，和时间对应
      property.addSample(time, position);
    }
    return property;
  }

  start() {
    if (this.entity) {
      console.warn("实体已经初始化")
      return
    }
    this.init()
  }

  stop() {
    this.entity ? (this.entity.show = false) : ''
  }

  uninstall() {
    if (!this.entity) return
    this.viewer.entities.remove(this.entity)
    this.entity = null
  }

  zoomTo() {
    this.viewer.zoomTo(this.entity)
  }
}

export default FlyWithTime
